@@ -14,10 +14,10 @@
 #include <QCoreApplication>
 #include <QDir>
 #include <QHash>
+#include <QList>
 #include <QLocale>
 #include <QMap>
 #include <QPluginLoader>
-#include <QVector>
 
 #include <algorithm>
 
@@ -36,7 +36,7 @@ public:
     SettingsImpl *settings;
 
     // <language, Clients with that language >
-    QMap<QString, QVector<Client *>> languageClients;
+    QMap<QString, QList<Client *>> languageClients;
     QStringList clients;
 
     QSet<QString> loadedPlugins;
@@ -69,7 +69,6 @@ Loader::~Loader()
     qCDebug(SONNET_LOG_CORE) << "Removing loader: " << this;
     delete d->settings;
     d->settings = nullptr;
-    delete d;
 }
 
 SpellerPlugin *Loader::createSpeller(const QString &language, const QString &clientName) const
@@ -92,7 +91,7 @@ SpellerPlugin *Loader::createSpeller(const QString &language, const QString &cli
         return nullptr;
     }
 
-    const QVector<Client *> lClients = *clientsItr;
+    const QList<Client *> lClients = *clientsItr;
 
     if (backend.isEmpty()) {
         backend = d->settings->defaultClient();
@@ -109,7 +108,7 @@ SpellerPlugin *Loader::createSpeller(const QString &language, const QString &cli
         }
     }
 
-    QVectorIterator<Client *> itr(lClients);
+    QListIterator<Client *> itr(lClients);
     while (itr.hasNext()) {
         Client *item = itr.next();
         if (!backend.isEmpty()) {
@@ -228,7 +227,7 @@ QString Loader::languageNameForCode(const QString &langCode) const
     }
 
     QLocale locale(isoCode);
-    localizedCountry = locale.nativeCountryName();
+    localizedCountry = locale.nativeTerritoryName();
     localizedLang = locale.nativeLanguageName();
 
     if (localizedLang.isEmpty() && localizedCountry.isEmpty()) {
@@ -272,7 +271,7 @@ void Loader::loadPlugins()
 {
 #ifndef SONNET_STATIC
     const QStringList libPaths = QCoreApplication::libraryPaths() << QStringLiteral(INSTALLATION_PLUGIN_PATH);
-    const QString pathSuffix(QStringLiteral("/kf" QT_STRINGIFY(QT_VERSION_MAJOR)) + QStringLiteral("/sonnet/"));
+    const QString pathSuffix(QStringLiteral("/kf6/sonnet/"));
     for (const QString &libPath : libPaths) {
         QDir dir(libPath + pathSuffix);
         if (!dir.exists()) {
@@ -335,7 +334,7 @@ void Loader::loadPlugin(const QString &pluginPath)
     d->clients.append(client->name());
 
     for (const QString &language : languages) {
-        QVector<Client *> &languageClients = d->languageClients[language];
+        QList<Client *> &languageClients = d->languageClients[language];
 
         if (languageClients.isEmpty() //
             || client->reliability() < languageClients.first()->reliability()) {
@@ -351,3 +350,5 @@ void Loader::changed()
     Q_EMIT configurationChanged();
 }
 }
+
+#include "moc_loader_p.cpp"
